<?php

namespace FiloBlu\ExtViSualMerchandiser\Helper;

use Magento\CatalogInventory\Model\Stock;
use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\ObjectManagerInterface;
use Magento\Inventory\Model\StockRepository;
use Magento\InventoryApi\Api\StockRepositoryInterface;
use Magento\Store\Model\ScopeInterface;

/**
 * Class ConfigHelper
 * @package FiloBlu\ExtViSualMerchandiser\Helper
 */
class ConfigHelper extends AbstractHelper
{
    /** @var string  */
    const CONFIG_DEFAULT_STOCK = 'visualmerchandiser/options/default_stock';

    /**
     * @var array
     */
    protected $availableStocks = [];

    /**
     * @var ObjectManagerInterface
     */
    private $objectManager;

    /**
     * ConfigHelper constructor.
     * @param Context $context
     * @param ObjectManagerInterface $objectManager
     */
    public function __construct(Context $context, ObjectManagerInterface $objectManager)
    {
        parent::__construct($context);
        $this->objectManager = $objectManager;
    }

    /**
     * Returns stocks available on current Magento2 installation
     *
     * @return array [ stock_id -> stock_label ]
     */
    public function getAvailableStocks()
    {
        if(!empty($this->availableStocks))
        {
            return $this->availableStocks;
        }

        if (!$this->isMultistockAvailable()) {
            $this->availableStocks[Stock::DEFAULT_STOCK_ID] = 'Default';
            return $this->availableStocks;
        }

        /** @var  StockRepository $stockRepository */
        $stockRepository = $this->objectManager->get(StockRepositoryInterface::class);

        $stockList = $stockRepository->getList();

        foreach ($stockList->getItems() as $stock) {
            $this->availableStocks[$stock->getStockId()] = $stock->getName();
        }

        return $this->availableStocks;
    }

    /**
     * @return bool
     */
    public function isMultistockAvailable()
    {
        return $this->_moduleManager->isEnabled('Magento_Inventory');
    }

    /**
     * @return int
     */
    public function getSelectedDefaultStockId()
    {
        $stock = $this->scopeConfig->getValue(ConfigHelper::CONFIG_DEFAULT_STOCK, ScopeInterface::SCOPE_STORE);
        if ($stock) {
            return (int)$stock;
        }
        return Stock::DEFAULT_STOCK_ID;
    }
}
